"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var commander_1 = require("commander");
var build_1 = require("./build");
var utils_1 = require("./utils");
var getBuildOptions_1 = require("./config/getBuildOptions");
var paths_1 = require("./config/paths");
var test_1 = require("./test");
var lint_1 = require("./lint");
var format_1 = require("./format");
var watch_1 = require("./watch");
var constants_1 = require("./config/constants");
var program = new commander_1.Command();
program.version(paths_1.VERSION);
program
    .command('build')
    .description("\n    \u6784\u5EFA\u9879\u76EE\u3002\u5C06TypeScript\u7F16\u8BD1\u6210js\u3002\n\n    \u4F8B\u5B50\uFF1A\n\n    $ build\n    $ build --format cjs,es,umd\n    $ build --entry src/example.ts\n    $ build --target node\n  ")
    .option('-f, --format <format>', '指定模块格式，默认为cjs,es', utils_1.commaSeparatedList, ['cjs', 'es'])
    .option('--entry, -i <entry>', '指定入口文件，默认为src/index.ts或者src/index.tsx')
    .option('--target <target>', '指定目标环境，可选项为web、node，默认为web', 'web')
    .option('--name <name>', '指定在UMD中的名称，默认会取package.json中的name')
    .option('--outDir <outDir>', "\u6307\u5B9A\u8F93\u51FA\u76EE\u5F55\uFF0C\u9ED8\u8BA4\u4E3A" + constants_1.DIST_PATH_NAME, constants_1.DIST_PATH_NAME)
    .action(function (options) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, build_1.runBuild(getBuildOptions_1.getBuildOptions(options))];
            case 1:
                _a.sent();
                return [2 /*return*/];
        }
    });
}); });
program
    .command('watch')
    .description("\u4EE5\u76D1\u542C\u6A21\u5F0F\u542F\u52A8\u9879\u76EE\u3002\u6BCF\u5F53\u4EE3\u7801\u53D1\u751F\u53D8\u5316\u5C31\u4F1A\u91CD\u65B0\u7F16\u8BD1\u3002\n\n  \u4F8B\u5B50\uFF1A\n\n    $ watch\n    $ watch --format cjs,es,umd\n    $ watch --entry src/example.ts\n    $ watch --target node\n  ")
    .option('-f, --format <format>', '指定模块格式，默认为cjs,es', utils_1.commaSeparatedList, ['cjs', 'es'])
    .option('--entry, -i <entry>', '指定入口文件，默认为src/index.ts或者src/index.tsx')
    .option('--target <target>', '指定目标环境，可选项为web、node，默认为web', 'web')
    .option('--name <name>', '指定在UMD中的名称，默认会取package.json中的name')
    .option('--outDir <outDir>', "\u6307\u5B9A\u8F93\u51FA\u76EE\u5F55\uFF0C\u9ED8\u8BA4\u4E3A" + constants_1.DIST_PATH_NAME, constants_1.DIST_PATH_NAME)
    .action(function (options) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, watch_1.runWatch(getBuildOptions_1.getBuildOptions(options))];
            case 1:
                _a.sent();
                return [2 /*return*/];
        }
    });
}); });
program.command('lint').description('代码检查');
program.command('test').description('单元测试');
program.command('format').description('格式化代码');
var command = process.argv[2];
if (command === 'test') {
    test_1.test();
}
else if (command === 'lint') {
    lint_1.lint();
}
else if (command === 'format') {
    format_1.format();
}
else {
    program.parse(process.argv);
}
//# sourceMappingURL=index.js.map